==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/SortIndicatorRenderCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SortIndicatorRenderCompletedEventArgsDescription } from "./SortIndicatorRenderCompletedEventArgsDescription";
/**
 * @hidden
 */
var SortIndicatorRenderCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SortIndicatorRenderCompletedEventArgsDescriptionMetadata, _super);
    function SortIndicatorRenderCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a == null) {
            SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SortIndicatorRenderCompletedEventArgsDescriptionMetadata.c(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.k(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
    };
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.c = function (a) {
    };
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.d = function (a) {
        SortIndicatorRenderCompletedEventArgsDescriptionMetadata.b(a);
        a.ad("SortIndicatorRenderCompletedEventArgs", function () { return new SortIndicatorRenderCompletedEventArgsDescription(); });
        a.ac("SortIndicatorRenderCompletedEventArgs", SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
    };
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.$t = markType(SortIndicatorRenderCompletedEventArgsDescriptionMetadata, 'SortIndicatorRenderCompletedEventArgsDescriptionMetadata');
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a = null;
    return SortIndicatorRenderCompletedEventArgsDescriptionMetadata;
}(Base));
export { SortIndicatorRenderCompletedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/SortIndicatorRenderCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SortIndicatorRenderCompletedEventArgsDescription } from "./SortIndicatorRenderCompletedEventArgsDescription";
/**
 * @hidden
 */
var SortIndicatorRenderCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SortIndicatorRenderCompletedEventArgsDescriptionMetadata, _super);
    function SortIndicatorRenderCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a == null) {
            SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SortIndicatorRenderCompletedEventArgsDescriptionMetadata.c(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.k(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
    };
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.c = function (a) {
    };
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.d = function (a) {
        SortIndicatorRenderCompletedEventArgsDescriptionMetadata.b(a);
        a.ae("SortIndicatorRenderCompletedEventArgs", function () { return new SortIndicatorRenderCompletedEventArgsDescription(); });
        a.ad("SortIndicatorRenderCompletedEventArgs", SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
    };
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.$t = markType(SortIndicatorRenderCompletedEventArgsDescriptionMetadata, 'SortIndicatorRenderCompletedEventArgsDescriptionMetadata');
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a = null;
    return SortIndicatorRenderCompletedEventArgsDescriptionMetadata;
}(Base));
export { SortIndicatorRenderCompletedEventArgsDescriptionMetadata };
